==> cvsync-0.24.13.tar.gz: cvsync-0.24.13/cvsync/defs.h <==
/*-
 * Copyright (c) 2000-2003 MAEKAWA Masahide <maekawa@cvsync.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef __DEFS_H__
#define	__DEFS_H__

struct config {
	struct config		*cf_next;
	char			cf_host[CVSYNC_MAXHOST];
	char			cf_serv[CVSYNC_MAXSERV];
	char			cf_base[PATH_MAX], cf_base_prefix[PATH_MAX];
	int			cf_family;
	int			cf_compress;
	uint8_t			cf_hash;
	uint32_t		cf_proto;
	uint16_t		cf_mss;
	struct collection	*cf_collections;
};

struct config *config_load_file(const char *);
struct config *config_load_uri(const char *);
void config_destroy(struct config *);

struct mux *channel_establish(int, struct config *);
boolean collectionlist_exchange(int, struct config *);
boolean compress_exchange(int, struct config *);
boolean hash_exchange(int, struct config *);
boolean protocol_exchange(int, struct config *);

#endif /* __DEFS_H__ */

==> cvsync-0.24.18.tar.gz: cvsync-0.24.18/cvsync/defs.h <==
/*-
 * Copyright (c) 2000-2004 MAEKAWA Masahide <maekawa@cvsync.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef __DEFS_H__
#define	__DEFS_H__

struct config {
	struct config		*cf_next;
	char			cf_host[CVSYNC_MAXHOST];
	char			cf_serv[CVSYNC_MAXSERV];
	char			cf_base[PATH_MAX], cf_base_prefix[PATH_MAX];
	int			cf_family;
	int			cf_compress;
	uint8_t			cf_hash;
	uint32_t		cf_proto;
	uint16_t		cf_mss;
	struct collection	*cf_collections;
};

struct config *config_load_file(const char *);
struct config *config_load_uri(const char *);
void config_destroy(struct config *);

struct mux *channel_establish(int, struct config *);
bool collectionlist_exchange(int, struct config *);
bool compress_exchange(int, struct config *);
bool hash_exchange(int, struct config *);
bool protocol_exchange(int, struct config *);

#endif /* __DEFS_H__ */
